.. _usage-library:

=============
Library Usage
=============

You will be most interested in using the API client library from the ``clinvar_api`` Python package:

.. code-block:: python

    import clinvar_api
